Processors#
Data Processors#
Text#
|
Text fuzzy deduplication using MinHashLSH. |
Implements a scalable, distributed exact substring deduplication algorithm using a divide-and-conquer strategy. |
Audio#
|
Image#
|
Video#
|
AI Processors#
Text#
|
Text Embedding processor for CPU, GPU and remote Http requests. |
|
TextSummarize processor provides a highly condensed summary of the text. |
|
TextMask processor replaces sensitive information in the original text with [MASKED] according to the labels. |
|
TextGenerate processor generates content based on the input parameters. |
|
TextClassify processor extracts the single label string that best matches the text content from the given labels. |
|
TextFixGrammar processor corrects grammar mistakes in the input text using LLM model. |
|
TextSimilarity processor calculates similarity between texts using LLM model. |
|
TextTranslate processor responsible for translating the text into the target language. |
|
TextSentiment processor for text sentiment analysis. |
|
TextExtract processor extracts structured information from text based on user-defined |
|
TextPredicateEval processor evaluates whether input texts satisfy a given predicate condition. |
Image#
|
Image NSFW score calculation processor for CPU, GPU |
Image text similarity score calculation processor for CPU, GPU |
|
Image aesthetic score calculation processor for CPU, GPU. |
Audio#
|
Speech to text processor for CPU, GPU and remote Http requests. |